     function [pmb,tc,density] = std76(hghm)
%
%      Standard Atmosphere 1976  pressure, tempature vs height
%
%    input:
%              hghm      height above geoid in m (geopotential meters realy)
%    output:
%              pmb       pressure     mbar
%              tc        temperature  deg C
%              density   density      kg/m**3
%
%    good 0 m to 85 km.  Doesn't do high altitude STD 76 model
%    below 0,  extrapolates down at constant temperature
%
%    jrc  6-24-02
%
%         Standard Atmosphere 1976 Constants / Defination 
%
%  
%         --------------------------------------------------
%
    pzero   =   1013.250;     % mb
    gstda   =    9.80665;     % m/s/s
    Rstar   =  8.31432E3;     % Universal Gas Constant N-m/(kmole-K)
    Mzero   =  28.9644;       % kg/kmole
    abszero = -273.15;        % deg K
%
    Rconst  =  1.0D-2 * Rstar/Mzero;
%
%     layers  in geopotential meters
%
%         h = base of layer - km
%         T = temperature at base - deg C
%         L = lapse rate  = temperature gradient deg/km
%
%              Level 8 in table just to have a top to level 8
%
     h = zeros(1,8);        t= zeros(1,8);       L=zeros(1,8);
%           km                 deg-C               deg-K/km
%
     h(1)  =      0.0;      t(1) =  15.0;        L(1) = -6.5;
     h(2)  =  11.0000;      t(2) = -56.5;        L(2) =  0.0;
     h(3)  =  20.0000;      t(3) = -56.5;        L(3) =  1.0;
     h(4)  =  32.0000;      t(4) = -44.5;        L(4) =  2.8;
     h(5)  =  47.0000;      t(5) = - 2.5;        L(5) =  0.0;
     h(6)  =  51.0000;      t(6) = - 2.5;        L(6) = -2.8;
     h(7)  =  71.0000;      t(7) = -58.5;        L(7) = -2.0;
     h(8)  =  84.8522;      t(8) = -86.2;        L(8) =  0.0;
%
%    ----------------------------------------------------------------
%
     p = zeros(1,8);
%
     p(1)  = 1013.2500;
     p(2)  =  226.32064;
     p(3)  =   54.748887;
     p(4)  =    8.680187;
     p(5)  =    1.109063;
     p(6)  =    0.6693887;
     p(7)  =    0.0395642;
     p(8)  =    0.00373520;
%
%    ----------------------------------------------------------------
%
%    ----  do vector inputs via a loop  ----
%
     szhgh =  size(hghm);
     hghv  =  hghm(:);
%
     len   =  length ( hghv );
%
     pmbi     =  [];
     tci      =  [];
     densityi =  [];
%     
     for  ihgh = 1:len
%
          hkm  =  hghv(ihgh)/1000.0;
%
%         find layer in
%
          ixgt  =  [];
          ixgt  =  find ( hkm >= h );
%
          if isempty(ixgt)
              i    = 1;
              grad = 0;
          else
              ixx  = length( ixgt );
              i    = ixgt(ixx);
              grad = L(i);
          end
%
          tkbot  = t(i) - abszero;
          hbot   = h(i);
          pbot   = p(i);
%
          tk     = tkbot + grad * ( hkm - hbot );
%
          if abs(grad) < 0.1e-2
%
              gxdist = 1000.0 * gstda * ( hkm - hbot );
              expval = gxdist * Mzero / (Rstar*tkbot);
              pnow   = pbot * exp( -expval );
%
           else
%
              tratio   =  tkbot/tk;
              gxdist_k =  1000.0*gstda/grad;
              expval   =  gxdist_k * Mzero / Rstar;
              pnow     =  pbot * (tratio^expval);
%
           end
%
           tci(ihgh)      =  tk + abszero;
           pmbi(ihgh)     =  pnow;
           densityi(ihgh) =  pnow / (Rconst*tk);
%
%
     end
%
     n  =  szhgh(1);
     m  =  szhgh(2);
%
     tc       =  reshape ( tci,n,m );
     pmb      =  reshape ( pmbi,n,m);
     density  =  reshape ( densityi,n,m);
%
     return
