      function  rng_trop = troprng ( elv, tc, pres, rh )
%
%         tropospheric range from elv, and surface weather data
%         Kuba, - 3rd Doppler Symp.// Improved Hal Black Model //
%
%    input:
%              elv            elevation angle deg
%              tc             temperature, deg C
%              pres           SURFACE pressure, millibars
%              rh             relative humidity - percent (0 to 100)
%    output:
%              rng_trop       tropospheric range, meters
%
%         notes:
%              1.   probably bad below 5 degrees elv.
%              2.   surface, not "sea level adjusted" pressures
%                   ("Station Pressure")
%              3.   Assumes exponential atmosphere and water vapor
%
%  == Careful in Matlab use:  Has not been "vectorized"  ==
%
%    modhist:
%         6-12-02   jrc from fortran program anltrop
%
%         -------------------------------------------------
%
%         simple spherical earth okay -- only counts near ground
%
       re   = 6378145.0;
%
%              parameters to science units
%
       pa      =  pres/1013.25;
       tk      =  tc + 273.0;
%
%              scale lengths
%
       slw  = 12000.0;
       sld  = 148.98 * ( tk - 3.96) ;
%
%         compute the partial pressure h2o - if saturated
%         then for relative humidity
%
       tks   = tk*tk;
       ekke  = -37.2465 + 0.213166*tk - 0.256908E-3*tks;
       ekks  = exp ( ekke );
       ekk   = (rh/100.0) * ekks ;
%
%         wet and dry factors
%              ds = delta range, wn=wet, dn = dry  - at zenith
%
       answ  = 3.73e5 * ekk /tks ;
       dswn  = (answ/5.0) * slw * 1.0e-6;
       domw  = 1.0 + 0.15*slw / re;
%
       dsdn  = 2.343*pa*(tk-3.96)/tk;
       domd  = 1.0 + 0.15*sld / re;
%
%              obliquity function at elv given
%
       dtr   = pi/180;
       ce    = cos(dtr*elv);
%
%           (vectorize the elv angle, NOT surface weather parameters)
%
       ratiod = 1.0 - (ce./domd).^2;
       ratiow = 1.0 - (ce./domw).^2;
%
%              apply the obliquity factor to the normal (zenith)
%              values
%
       dsd    = dsdn ./ sqrt( ratiod );
       dsw    = dswn ./ sqrt( ratiow );
%
       rng_trop =  dsd + dsw ;
%
       return
